### Name: default.QP
### Title: Generating a default Quadratic Program for bmonomvn
### Aliases: default.QP
### Keywords: optimize

### ** Examples

## generate N=100 samples from a 10-d random MVN
## and randomly impose monotone missingness
xmuS <- randmvn(100, 20)
xmiss <- rmono(xmuS$x)

## set up the minimum-variance (default) Quadratic Program
## and sample from the posterior of the solution space
qp1 <- default.QP(ncol(xmiss))
obl1 <- bmonomvn(xmiss, QP=qp1)
m1 <- monomvn.solve.QP(obl1$S, qp1) ## calculate mean

## now obtain samples from the solution space of the
## mean-variance QP
qp2 <- default.QP(ncol(xmiss), dmu=TRUE)
obl2 <- bmonomvn(xmiss, QP=qp2)
m2 <- monomvn.solve.QP(obl2$S, qp2, obl2$mu) ## calculate mean

## now obtain samples from minimum variance solutions
## where the mean weighted (samples) are constrained to be
## greater one
qp3 <- default.QP(ncol(xmiss), mu.constr=1)
obl3 <- bmonomvn(xmiss, QP=qp3)
m3 <- monomvn.solve.QP(obl3$S, qp3, obl3$mu) ## calculate mean

## plot a comparison
par(mfrow=c(3,1))
plot(obl1, which="QP", xaxis="index", main="Minimum Variance")
points(m1, col=3, pch=18) ## add mean
plot(obl2, which="QP", xaxis="index", main="Mean Variance")
points(m2, col=3, pch=18) ## add mean
plot(obl3, which="QP", xaxis="index", main="Minimum Variance, mean >= 1")
points(m3, col=3, pch=18) ## add mean

## for a further comparison of samples of the QP solution
## w under Bayesian and non-Bayesian monomvn, see the
## examples in the bmonomvn help file



